# Operation

## ::: xdsl.ir.Operation

    options:
      members:
        - name
        - operands
        - results
        - successors
        - properties
        - attributes
        - regions
        - parent
        - next_op
        - prev_op
        - traits
      show_root_heading: true

## ::: xdsl.ir.OpOperands

    options:
      show_root_heading: true

## ::: xdsl.ir.OpTraits

    options:
      show_root_heading: true
